<?php
/**
 * Logo Slider Options
 *
 * @package Focus_Stock_Dark
 */

/**
 * Add hero content options to theme options
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function focus_stock_dark_logo_slider_options( $wp_customize ) {
	$wp_customize->add_section( 'focus_stock_logo_slider', array(
			'panel' => 'focus_stock_theme_options',
			'title' => esc_html__( 'Logo Slider', 'focus-stock-dark' ),
		)
	);

	focus_stock_register_option( $wp_customize, array(
			'name'              => 'focus_stock_logo_slider_option',
			'default'           => 'disabled',
			'sanitize_callback' => 'focus_stock_sanitize_select',
			'choices'           => focus_stock_section_visibility_options(),
			'label'             => esc_html__( 'Enable on', 'focus-stock-dark' ),
			'section'           => 'focus_stock_logo_slider',
			'type'              => 'select',
		)
	);

	focus_stock_register_option( $wp_customize, array(
			'name'              => 'focus_stock_logo_slider_sub_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'focus_stock_is_logo_slider_active',
			'label'             => esc_html__( 'Section Tagline', 'focus-stock-dark' ),
			'section'           => 'focus_stock_logo_slider',
			'type'              => 'text',
		)
	);

	focus_stock_register_option( $wp_customize, array(
			'name'              => 'focus_stock_logo_slider_title',
			'sanitize_callback' => 'wp_kses_post',
			'active_callback'   => 'focus_stock_is_logo_slider_active',
			'label'             => esc_html__( 'Section Title', 'focus-stock-dark' ),
			'section'           => 'focus_stock_logo_slider',
			'type'              => 'text',
		)
	);

	focus_stock_register_option( $wp_customize, array(
			'name'              => 'focus_stock_logo_slider_number',
			'default'           => '6',
			'sanitize_callback' => 'focus_stock_sanitize_number_range',

			'active_callback'   => 'focus_stock_is_logo_slider_active',
			'description'       => esc_html__( 'Save and refresh the page if No. of Items is changed (Max no of slides is 20)', 'focus-stock-dark' ),
			'input_attrs'       => array(
				'style' => 'width: 100px;',
				'min'   => 0,
				'max'   => 20,
				'step'  => 1,
			),
			'label'             => esc_html__( 'No of Items', 'focus-stock-dark' ),
			'section'           => 'focus_stock_logo_slider',
			'type'              => 'number',
		)
	);

	$logo_slider_number = get_theme_mod( 'focus_stock_logo_slider_number', 6 );

	for ( $i = 1; $i <= $logo_slider_number ; $i++ ) {
		// Page Sliders
		focus_stock_register_option( $wp_customize, array(
				'name'              => 'focus_stock_logo_slider_page_' . $i,
				'sanitize_callback' => 'focus_stock_sanitize_post',
				'active_callback'   => 'focus_stock_is_logo_slider_active',
				'label'             => esc_html__( 'Page', 'focus-stock-dark' ) . ' # ' . $i,
				'section'           => 'focus_stock_logo_slider',
				'type'              => 'dropdown-pages',
			)
		);
	} // End for().
}
add_action( 'customize_register', 'focus_stock_dark_logo_slider_options' );

/** Active Callback Functions */

if ( ! function_exists( 'focus_stock_is_logo_slider_active' ) ) :
	/**
	* Return true if logo_slider is active
	*
	* @since 1.0.0
	*/
	function focus_stock_is_logo_slider_active( $control ) {
		$enable = $control->manager->get_setting( 'focus_stock_logo_slider_option' )->value();

		//return true only if previwed page on customizer matches the type option selected
		return focus_stock_check_section( $enable );
	}
endif;
